# HarvesterPy

A Python library and Ansible role to interface with SUSE's Harvester HCI.

## Overview

HarvesterPy provides a comprehensive Python interface to the [SUSE Harvester HCI API](https://docs.harvesterhci.io/v1.6/api/). It simplifies interaction with Harvester resources such as virtual machines, images, volumes, networks, and more.